from PrimaryHeader import PrimaryHeader
from ImageStructureHeader import ImageStructureHeader
from ImageNavigationHeader import ImageNavigationHeader
from ImageDataHeader import ImageDataHeader
from AnnotationHeader import AnnotationHeader
from TimestampHeader import TimestampHeader
from AncillaryTextHeader import AncillaryTextHeader
from KeyHeader import KeyHeader
from ImageSegmentIdentificationHeader import ImageSegmentIdentificationHeader
from NOAALRITHeader import NOAALRITHeader
from HeaderStructureHeader import HeaderStructureHeader
from RiceCompressionHeader import RiceCompressionHeader
from DataFilenameHeader import DataFilenameHeader
from InvalidHeaderException import InvalidHeaderException
import time

##
# @brief Header Factory
# @details Generates the appropriate header object from data
# @author Miguel Dominguez
# @date 2016
class HeaderFactory(object):

    ##
    # @fn getHeader
    # @brief Extract header of any type from data.
    # @details Factory that allows the developer to extract a header object
    # from a series of unsigned bytes without necessarily knowing which
    # header is to be extracted next.
    # @param[in] data Unsigned bytes that contain header data
    # @param[out] header Relevant header object
    # @param[out] data Original data with header bytes "chomped" off
    @staticmethod
    def getHeader(data):
        headerType = data[0]
        header = None
        if headerType == PrimaryHeader.headerIndex():
            header = PrimaryHeader()
        elif headerType == ImageStructureHeader.headerIndex():
            header = ImageStructureHeader()
        elif headerType == ImageNavigationHeader.headerIndex():
            header = ImageNavigationHeader()
        elif headerType == ImageDataHeader.headerIndex():
            header = ImageDataHeader()
        elif headerType == AnnotationHeader.headerIndex():
            header = AnnotationHeader()
        elif headerType == TimestampHeader.headerIndex():
            header = TimestampHeader()
        elif headerType == AncillaryTextHeader.headerIndex():
            header = AncillaryTextHeader()
        elif headerType == KeyHeader.headerIndex():
            header = KeyHeader()
        elif headerType == ImageSegmentIdentificationHeader.headerIndex():
            header = ImageSegmentIdentificationHeader()
        elif headerType == NOAALRITHeader.headerIndex():
            header = NOAALRITHeader()
        elif headerType == HeaderStructureHeader.headerIndex():
            header = HeaderStructureHeader()
        elif headerType == RiceCompressionHeader.headerIndex():
            header = RiceCompressionHeader()
        elif headerType == DataFilenameHeader.headerIndex():
            header = DataFilenameHeader()
        else:
            raise InvalidHeaderException(headerType)
        data = header.getHeader(data)
        return (header, data)
