from AbstractHeader import AbstractHeader

##
# @brief Header Structure class.
# @details Contains an encoded text description of the contents of the full
# LRIT file header. Can be used to sanity check file if it is included
# @author Miguel Dominguez
# @date 2016
# @todo Create a function that parses the structure string into something that
# can be used by the program to sanity check the headers so far
class HeaderStructureHeader(AbstractHeader):

   ##
   # @fn headerIndex
   # @brief Return the header index of an Annotation Header.
   # @param[out] output Always 130
   @staticmethod
   def headerIndex():
      return 130

   ##
   # @fn getHeader
   # @brief Extract header data from input bytes.
   # @details This function extracts header data from a buffer and stores it
   # within the object.  A version of the data buffer with the header bytes
   # chomped off is returned
   # @param[in] Raw unsigned bytes that contain the header at the beginning
   # @param[out] The input buffer with header bytes removed
   def getHeader(self,data):
      self.headerRecordLength = (data[1] << self.BYTE_SHIFT) | data[2]
      self.structure = "".join(map(chr,data[3:self.headerRecordLength]))
      return data[self.headerRecordLength:len(data)]

   ##
   # @fn __str__
   # @brief Returns formatted header information as a string
   # @param[out] str Header information as a string
   def __str__(self):
      output = "Header Structure Header\n"
      output += "Header Record Length: {0}\n".format(self.headerRecordLength)
      output += "Structure String: {0}\n".format(self.structure)
      return output
